﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/sagemaker/SageMaker_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace SageMaker
{
namespace Model
{

  /**
   * <p>Priority class configuration. When included in <code>PriorityClasses</code>,
   * these class configurations define how tasks are queued.</p><p><h3>See Also:</h3>
   * <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24/PriorityClass">AWS
   * API Reference</a></p>
   */
  class PriorityClass
  {
  public:
    AWS_SAGEMAKER_API PriorityClass();
    AWS_SAGEMAKER_API PriorityClass(Aws::Utils::Json::JsonView jsonValue);
    AWS_SAGEMAKER_API PriorityClass& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_SAGEMAKER_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>Name of the priority class.</p>
     */
    inline const Aws::String& GetName() const{ return m_name; }
    inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
    inline void SetName(const Aws::String& value) { m_nameHasBeenSet = true; m_name = value; }
    inline void SetName(Aws::String&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
    inline void SetName(const char* value) { m_nameHasBeenSet = true; m_name.assign(value); }
    inline PriorityClass& WithName(const Aws::String& value) { SetName(value); return *this;}
    inline PriorityClass& WithName(Aws::String&& value) { SetName(std::move(value)); return *this;}
    inline PriorityClass& WithName(const char* value) { SetName(value); return *this;}
    ///@}

    ///@{
    /**
     * <p>Weight of the priority class. The value is within a range from 0 to 100,
     * where 0 is the default.</p> <p>A weight of 0 is the lowest priority and 100 is
     * the highest. Weight 0 is the default.</p>
     */
    inline int GetWeight() const{ return m_weight; }
    inline bool WeightHasBeenSet() const { return m_weightHasBeenSet; }
    inline void SetWeight(int value) { m_weightHasBeenSet = true; m_weight = value; }
    inline PriorityClass& WithWeight(int value) { SetWeight(value); return *this;}
    ///@}
  private:

    Aws::String m_name;
    bool m_nameHasBeenSet = false;

    int m_weight;
    bool m_weightHasBeenSet = false;
  };

} // namespace Model
} // namespace SageMaker
} // namespace Aws
